==> bigloo2.0a.tar.gz: bigloo2.0a/bmacs/bee/bee-autoload.el <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/bmacs/bee/bee-autoload.el            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Aug  1 10:27:42 1998                          */
;*    Last change :  Fri Feb 12 08:32:37 1999 (serrano)                */
;*    -------------------------------------------------------------    */
;*    All the autoload delcarations.                                   */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(provide 'bee-autoload)

;; bee-repl
(autoload 'bee-repl-other-frame        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-region        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-buffer        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-define        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-last-sexp     "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-toplevel-sexp "bee-repl" "Read-eval-print loop." t)
;; bee-indent
(autoload 'bee-external-indent         "bee-indent" "Indent source code." t)
(autoload 'bee-indent-define           "bee-indent" "Indent source code." t)
(autoload 'bee-indent-toplevel-sexp    "bee-indent" "Indent source code." t)
(autoload 'bee-indent-last-sexp        "bee-indent" "Indent source code." t)
(autoload 'bee-indent-region           "bee-indent" "Indent source code." t)
;; bee-module
(autoload 'bee-export-definition       "bee-module" "Bee module handling." t)
(autoload 'bee-import-binding          "bee-module" "Bee module handling." t)
(autoload 'bee-import-c-file           "bee-module" "Bee module handling." t)
(autoload 'bee-export-binding          "bee-module" "Bee module handling." t)
(autoload 'bee-export-function         "bee-module" "Bee module handling." t)
(autoload 'bee-export-variable         "bee-module" "Bee module handling." t)
(autoload 'bee-module-declaration-p    "bee-module" "Bee module handling." t)
(autoload 'bee-module-declaration-find "bee-module" "Bee module handling." t)
;; bee-expand
(autoload 'bee-expand-buffer           "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-define           "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-toplevel-sexp    "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-last-sexp        "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-region           "bee-expand" "Macro expansion." t)
;; bee-mouse
(autoload 'bee-add-menu                "bee-mouse" "Bee mouse handling." t)
;; bee-keymap
(autoload 'bee-add-region-popup-entry  "bee-keymap" "Bee keymap definition." t)
;; bee-tags
(autoload 'bee-find-module             "bee-tags" "Bee tags finder." t)
(autoload 'bee-find-module-nokeymap    "bee-tags" "Bee tags finder." t)
(autoload 'bee-find-module-list        "bee-tags" "Bee search engine." t)
(autoload 'bee-find-definition         "bee-tags" "Bee search engine." t)
(autoload 'bee-tags-find               "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-next          "bee-tags" "Bee tags finder." t)
(autoload 'bee-tag-find                "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-variable       "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-variable-noselect "bee-tags" "Bee tags finder." t)
;; bee-profile
(autoload 'bee-profile-highlight-buffer "bee-profile" "Bee profiler." t)
;; bee-usage
(autoload 'bee-find-local-definition   "bee-usage" "Bee variable usage." t)
(autoload 'bee-usage-find              "bee-usage" "Bee usage search." t)
;; bee-config
(autoload 'bee-customize               "bee-config" "Bee configuration." t)
;; bee-bdb
(autoload 'bee-bdb-init                "bee-bdb" "The Bdb connexion." t)
(autoload 'bdb-other-frame             "bee-bdb" "The Bdb connexion." t)
;; bee-flock
(autoload 'bee-font-lock-get-info-keywords "bee-flock" "Bee font lock." t)
(autoload 'bee-html-fontify-html-buffer    "bee-flock" "Bee font lock." t)

==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/bmacs/bee/bee-autoload.el <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/bmacs/bee/bee-autoload.el            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Aug  1 10:27:42 1998                          */
;*    Last change :  Thu Feb  1 23:56:24 2001 (serrano)                */
;*    -------------------------------------------------------------    */
;*    All the autoload delcarations.                                   */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(provide 'bee-autoload)

;; bee-repl
(autoload 'bee-repl-other-frame        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-region        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-buffer        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-define        "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-last-sexp     "bee-repl" "Read-eval-print loop." t)
(autoload 'bee-repl-send-toplevel-sexp "bee-repl" "Read-eval-print loop." t)
;; bee-indent
(autoload 'bee-external-indent         "bee-indent" "Indent source code." t)
(autoload 'bee-indent-define           "bee-indent" "Indent source code." t)
(autoload 'bee-indent-toplevel-sexp    "bee-indent" "Indent source code." t)
(autoload 'bee-indent-last-sexp        "bee-indent" "Indent source code." t)
(autoload 'bee-indent-region           "bee-indent" "Indent source code." t)
;; bee-module
(autoload 'bee-export-definition       "bee-module" "Bee module handling." t)
(autoload 'bee-import-binding          "bee-module" "Bee module handling." t)
(autoload 'bee-import-c-file           "bee-module" "Bee module handling." t)
(autoload 'bee-export-binding          "bee-module" "Bee module handling." t)
(autoload 'bee-export-function         "bee-module" "Bee module handling." t)
(autoload 'bee-export-variable         "bee-module" "Bee module handling." t)
(autoload 'bee-module-declaration-p    "bee-module" "Bee module handling." t)
(autoload 'bee-module-declaration-find "bee-module" "Bee module handling." t)
(autoload 'bee-get-module-name         "bee-module" "Bee module handling." t)
;; bee-expand
(autoload 'bee-expand-buffer           "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-define           "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-toplevel-sexp    "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-last-sexp        "bee-expand" "Macro expansion." t)
(autoload 'bee-expand-region           "bee-expand" "Macro expansion." t)
;; bee-mouse
(autoload 'bee-add-menu                "bee-mouse" "Bee mouse handling." t)
;; bee-keymap
(autoload 'bee-add-region-popup-entry  "bee-keymap" "Bee keymap definition." t)
;; bee-tags
(autoload 'bee-find-module             "bee-tags" "Bee tags finder." t)
(autoload 'bee-find-module-nokeymap    "bee-tags" "Bee tags finder." t)
(autoload 'bee-find-module-list        "bee-tags" "Bee search engine." t)
(autoload 'bee-find-definition         "bee-tags" "Bee search engine." t)
(autoload 'bee-tags-find               "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find/ident         "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-next          "bee-tags" "Bee tags finder." t)
(autoload 'bee-tag-find                "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-variable       "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-variable-noselect "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-exists-p           "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-if-exists-p   "bee-tags" "Bee tags finder." t)
(autoload 'bee-tags-find-or-info       "bee-tags" "Bee tags finder." t)
(autoload 'bee-find-afile-create-p     "bee-tags" "Bee tags finder." t)
;; bee-profile
(autoload 'bee-profile-highlight-buffer "bee-profile" "Bee profiler." t)
(autoload 'bee-profiler-start           "bee-profile" "Bee profiler." t)
(autoload 'bee-profiler-inspect         "bee-profile" "Bee profiler." t)
;; bee-jinsight
(autoload 'bee-jinsight-start          "bee-jinsight" "Jinsight viewer." t)
(autoload 'bee-jinsight-module-cpu     "bee-jinsight" "Jinsight viewer." t)
(autoload 'bee-jinsight-module-instances "bee-jinsight" "Jinsight viewer." t)
(autoload 'bee-jinsight-class-instances "bee-jinsight" "Jinsight viewer." t)
(autoload 'bee-jinsight-select-module  "bee-jinsight" "Jinsight viewer." t)
(autoload 'bee-jinsight-select-function  "bee-jinsight" "Jinsight viewer." t)
;; bee-browse
(autoload 'bee-browse-highlight-buffer "bee-browse" "Bee browser." t)
(autoload 'bee-browser-start           "bee-browse" "Bee browser." t)
(autoload 'bee-browser-ready-p         "bee-browse" "Bee ibuilder" t)
(autoload 'bee-browser-find-usage      "bee-browse" "Bee ibuilder" t)
;; bee-usage
(autoload 'bee-find-local-definition   "bee-usage" "Bee variable usage." t)
(autoload 'bee-usage-find              "bee-usage" "Bee usage search." t)
;; bee-config
(autoload 'bee-customize               "bee-config" "Bee configuration." t)
;; bee-bdb
(autoload 'bee-bdb-init                "bee-bdb" "The Bdb connection." t)
(autoload 'bdb-other-frame             "bee-bdb" "The Bdb connection." t)
;; bee-bdb
(autoload 'bee-kbdb-start              "bee-kbdb" "The Kbdb connection." t)
;; bee-flock
(autoload 'bee-font-lock-get-info-keywords "bee-flock" "Bee font lock." t)
(autoload 'bee-html-fontify-html-buffer    "bee-flock" "Bee font lock." t)
;; bee-ibuilder
(autoload 'bee-interface-builder-start      "bee-ibuilder" "Bee ibuilder" t)
(autoload 'bee-interface-builder-module-p   "bee-ibuilder" "Bee ibuilder" t)
(autoload 'bee-interface-builder-module     "bee-ibuilder" "Bee ibuilder" t)
(autoload 'bee-interface-builder-ready-p    "bee-ibuilder" "Bee ibuilder" t)
(autoload 'bee-find-interface-builder-module "bee-ibuilder" "Bee ibuilder" t)
;; bee-begoo
(autoload 'bee-begoo-ready-p           "bee-begoo" "The Begoo connection." t)
